@@ -153,10 +153,39 @@ QList<Device*> SfdiskBackend::scanDevices(const ScanFlags scanFlags)
  * and then a }. If there is, replace the ,.
  *
  * This is also fixed in util-linux 2.37.
+ *
+ * For some partition tables sfdisk prints an error message before the actual json
+ * starts (seen with sfdisk 2.37.4). It looks like this:
+ *
+ * omitting empty partition (5)
+ *  {
+ *  "partitiontable": {
+ *     "label": "dos",
+ *     "id": "0x91769176",
+ *     "device": "/dev/sdb",
+ *     "unit": "sectors",
+ *     "sectorsize": 512,
+ *     "partitions": [
+ *        {
+ *           "node": "/dev/sdb1",
+ *           "start": 63,
+ *           "size": 84630357,
+ *           "type": "7",
+ *           "bootable": true
+ *        },{
+ * etc.
  */
 static void
 fixInvalidJsonFromSFDisk( QByteArray& s )
 {
+    int jsonStart = s.indexOf('{');
+    if (jsonStart != 0) {
+        const QByteArray invalidStart = s.left(jsonStart);
+        qDebug() << "removed \"" << invalidStart.data() << "\" from beginning of sfdisk json output";
+        const QByteArray copy = s.mid(jsonStart);
+        s = copy;
+    }
+
     // -1 if there is no comma (but then there's no useful JSON either),
     //    not is 0 a valid place (the start) for a , in a JSON document.
     int lastComma = s.lastIndexOf(',');
@@ -265,6 +294,10 @@ Device* SfdiskBackend::scanDevice(const QString& deviceNode)
             const QJsonObject jsonObject = QJsonDocument::fromJson(s).object();
             const QJsonObject partitionTable = jsonObject[QLatin1String("partitiontable")].toObject();
 
+            if (jsonObject.isEmpty()) {
+                qDebug() << "json object created from sfdisk output is empty !\nOutput is \"" << s.data() << "\"";
+            }
+
             if (!updateDevicePartitionTable(*d, partitionTable))
                 return nullptr;
 
